California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 024 - AMENDS CONSUMER PRIVACY LAWS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1428087 | CALIFORNIA CONSUMER AND PRIVACY ADVOCATES AGAINST PROP 24, SPONSORED BY CALIFORNIA NURSES ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1430424 | CALIFORNIANS FOR REAL PRIVACY - NO ON PROPOSITION 24 SPONSORED BY CONSUMER FEDERATION OF CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1423771 | YES ON 24, CALIFORNIANS FOR CONSUMER PRIVACY | SUPPORT